export(fit_model)
export(predict_rul)
export(fit_healthindex)
export(plot_degradr)
export(compute_healthindex)
export(prul)
export(qrul)
importFrom(nlme, lme, fixed.effects, getVarCov)
import(dplyr)
import(quadprog)
import(ggplot2)
importFrom("stats", "AIC", "BIC", "as.formula", "logLik", "pnorm",
               "sigma", "var","coef", "cov", "lm", "residuals")
